use crate::{
    consts::RsaStrength,
    prelude::*,
};
use macro_rules_attribute::macro_rules_derive;
use schemars::JsonSchema;
use serde::Deserialize;


#[macro_rules_derive(DefDer)]
#[derive(Copy, Deserialize, Default, JsonSchema)]
pub enum Algorithm {
    Rsa,
    Brainpool,
    Secp,
    #[default]
    ED25519,
}


#[macro_rules_derive(DefDer)]
#[derive(Copy, Deserialize, Default, JsonSchema)]
#[serde(deny_unknown_fields)]
pub enum Strength {
    Weak,
    Middle,
    #[default]
    Strong,
}

impl Strength {
    pub fn rsabits(self) -> u32 {
        match self {
            Self::Weak => RsaStrength::Weak as u32,
            Self::Middle => RsaStrength::Middle as u32,
            Self::Strong => RsaStrength::Strong as u32,
        }
    }
}
